import os.path

import tq_img_utils as imutil

from test import join_base_dir as join_parent_base_dir


def test():
    img_path = r'E:\Workspace\Pycharm\Datasets\data\Dataset-DOWL2\DOWL2\zh\cctv\2k\1.png'
    bound = imutil.BoundingBox.get_from_two_points_format((840, 742, 901, 774))
    img = imutil.im_read(img_path)
    imutil.im_show('img', imutil.im_crop(img, bound))


def join_base_dir(path):
    path = join_parent_base_dir(os.path.join('img_operation', path))
    path = os.path.abspath(path)
    print(path)
    return path


def test_img_gray_binary_denoise():
    image = imutil.im_read(join_base_dir(r'1.jpg'))
    # 灰度化
    gray_image = imutil.average_grayscale(image)
    # 二值化
    binary_image = imutil.otsu_thresholding(gray_image)
    # 去噪
    denoise_image = imutil.denoise(binary_image)
    imutil.im_show('gray_image', gray_image)
    imutil.im_show('binary_image', binary_image)
    imutil.im_show('denoise_image', denoise_image)


def test_img_denoise():
    image = imutil.im_read(join_base_dir(r'opencv-noise.png'))
    imutil.im_show('image', image)
    denoise_image = imutil.denoise(image)
    imutil.im_show('denoise_image', denoise_image)
    denoise_image = imutil.denoise(image)
    imutil.im_show('denoise_image', denoise_image)
    denoise_image = imutil.denoise(image)
    imutil.im_show('denoise_image', denoise_image)


def test_img_draw_rectangle():
    image = imutil.im_read(join_base_dir(r'1.jpg'))
    imutil.im_show('image_draw', imutil.im_draw_rectangle(image, (0, 0, 300, 300)))
    imutil.im_show('image', image)



from tq_img_utils import BoundingBox


def test_area():
    print()
    try:
        BoundingBox(1, 1, 1, 3)
        BoundingBox(1, 1, -1, 3)
    except ValueError as e:
        print(e)  # The area of the bounding must be positive(w:-1, h:3).


def test_constrain():
    print()
    constraint = (2, 2)
    b = BoundingBox(0, 0, 2, 2, constraint)
    print(b)  # BoundingBox(x=0, y=0, width=2, height=2)
    b = BoundingBox(1, 1, 3, 3, constraint)
    print(b)  # BoundingBox(x=1, y=1, width=1, height=1)


def test_constrain_warn():
    print()
    constraint = (2, 2)
    try:
        BoundingBox(0, 0, 2, 2, constraint, True)
        BoundingBox(1, 1, 3, 3, constraint, True)
    except ValueError as e:
        print(e)  # The bounding(1, 1, 3, 3) is out of constraint(2, 2).
